#!/usr/bin/env python3
# -*- coding: utf-8 -*-
#
# License: GNU General Public License v2
#
# Author: thl-cmk[at]outlook[dot]com
# URL   : https://thl-cmk.hopto.org
# Date  : 2016-03-31
#
#  wato plugin for 'cisco_wlc_cpu'
#
#

from cmk.gui.i18n import _
from cmk.gui.valuespec import (
    Dictionary,
    Tuple,
    Integer,
)

from cmk.gui.plugins.wato.utils import (
    CheckParameterRulespecWithItem,
    rulespec_registry,
    RulespecGroupCheckParametersNetworking,
)


def _parameter_valuespec_cisco_wlc_cpu():
    return Dictionary(elements=[
        ('levels_upper',
         Tuple(
             title=_('Upper levels'),
             help=_('Set the maximum for CPU utilization in %'),
             elements=[
                 Integer(title=_('Warning at'), unit='%', default_value=70, minvalue=0, maxvalue=100),
                 Integer(title=_('Critical at'), unit='%', default_value=80, minvalue=0, maxvalue=100)
             ],
         ),
         ),
    ])


rulespec_registry.register(
    CheckParameterRulespecWithItem(
        check_group_name='cisco_wlc_cpu',
        group=RulespecGroupCheckParametersNetworking,
        match_type='dict',
        parameter_valuespec=_parameter_valuespec_cisco_wlc_cpu,
        title=lambda: _('Cisco WLC CPU utilization'),
    ))
